==> 0.0.3.tar.gz: lib/dgis_flutter.dart <==
import 'package:dgis_flutter/gis_map_controller.dart';
import 'package:dgis_flutter/model/gis_camera_position.dart';
import 'package:dgis_flutter/model/gis_map_object.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter/services.dart';

class GisMap extends StatelessWidget {
  final String directoryKey;
  final String mapKey;
  final GisCameraPosition startCameraPosition;
  final GisMapController controller;
  final List<GisMapMarker> markers;

  const GisMap(
      {Key? key,
      required this.mapKey,
      required this.directoryKey,
      required this.startCameraPosition,
      required this.markers,
      required this.controller})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    // This is used in the platform side to register the view.
    const String viewType = '<gis-view>';
    // Pass parameters to the platform side.
    Map<String, dynamic> creationParams = {
      'directory': directoryKey,
      'map': mapKey,
      'latitude': startCameraPosition.latitude,
      'longitude': startCameraPosition.longitude,
      'zoom': startCameraPosition.zoom,
      'tilt': startCameraPosition.tilt,
      'bearing': startCameraPosition.bearing,
      'markers' : markers.map((e) => e.toJson()).toList()
    };

    return PlatformViewLink(
      viewType: viewType,
      surfaceFactory: (context, controller) {
        return AndroidViewSurface(
          controller: controller as AndroidViewController,
          gestureRecognizers: const <Factory<OneSequenceGestureRecognizer>>{},
          hitTestBehavior: PlatformViewHitTestBehavior.opaque,
        );
      },
      onCreatePlatformView: (params) {
        return PlatformViewsService.initSurfaceAndroidView(
          id: params.id,
          viewType: viewType,
          layoutDirection: TextDirection.ltr,
          creationParams: creationParams,
          creationParamsCodec: const StandardMessageCodec(),
          onFocus: () {
            params.onFocusChanged(true);
          },
        )
          ..addOnPlatformViewCreatedListener(params.onPlatformViewCreated)
          ..create();
      },
    );
  }
}

==> 0.0.5.tar.gz: lib/dgis_flutter.dart <==
import 'package:dgis_flutter/gis_map_controller.dart';
import 'package:dgis_flutter/model/gis_camera_position.dart';
import 'package:dgis_flutter/model/gis_map_object.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter/services.dart';

class GisMap extends StatefulWidget {
  final String directoryKey;
  final String mapKey;
  final GisCameraPosition startCameraPosition;
  final GisMapController controller;
  final List<GisMapMarker> markers;
  final Function(GisMapMarker) onTapMarker;

  const GisMap(
      {Key? key,
      required this.mapKey,
      required this.directoryKey,
      required this.startCameraPosition,
      required this.markers,
      required this.controller,
      required this.onTapMarker})
      : super(key: key);

  @override
  State<GisMap> createState() => _GisMapState();
}

class _GisMapState extends State<GisMap> {
  final _methodCannel = const MethodChannel("fgis");

  @override
  initState() {
    _methodCannel
        .setMethodCallHandler((MethodCall call) => _handleMethodCall(call));
    super.initState();
  }

  Future<dynamic> _handleMethodCall(MethodCall call) async {
    switch (call.method) {
      case 'ontap_marker':
        String id = call.arguments['id'];
        widget.onTapMarker(widget.markers.firstWhere((element) =>
            element.id == id));
        break;
      default:
        throw MissingPluginException();
    }
  }

  @override
  Widget build(BuildContext context) {
    // This is used in the platform side to register the view.
    const String viewType = '<gis-view>';
    // Pass parameters to the platform side.
    Map<String, dynamic> creationParams = {
      'directory': widget.directoryKey,
      'map': widget.mapKey,
      'latitude': widget.startCameraPosition.latitude,
      'longitude': widget.startCameraPosition.longitude,
      'zoom': widget.startCameraPosition.zoom,
      'tilt': widget.startCameraPosition.tilt,
      'bearing': widget.startCameraPosition.bearing,
      'markers': widget.markers.map((e) => e.toJson()).toList()
    };

    return PlatformViewLink(
      viewType: viewType,
      surfaceFactory: (context, controller) {
        return AndroidViewSurface(
          controller: controller as AndroidViewController,
          gestureRecognizers: const <Factory<OneSequenceGestureRecognizer>>{},
          hitTestBehavior: PlatformViewHitTestBehavior.opaque,
        );
      },
      onCreatePlatformView: (params) {
        return PlatformViewsService.initSurfaceAndroidView(
          id: params.id,
          viewType: viewType,
          layoutDirection: TextDirection.ltr,
          creationParams: creationParams,
          creationParamsCodec: const StandardMessageCodec(),
          onFocus: () {
            params.onFocusChanged(true);
          },
        )
          ..addOnPlatformViewCreatedListener(params.onPlatformViewCreated)
          ..create();
      },
    );
  }
}
